@@ -3,15 +3,15 @@ package App::Action::TicketUpdate;
 
 
 use strict;
-use base qw( Workflow::Action );
-use Log::Log4perl qw( get_logger );
+use parent qw( Workflow::Action );
+use Log::Any qw( $log );
 use Workflow::History;
 
 $App::Action::TicketUpdate::VERSION = '1.05';
 
 sub execute {
     my ( $self, $wf ) = @_;
-    my $log = get_logger();
+
     $log->debug( "Action '", $self->name, "' with class ",
                  "'", ref( $self ), "' executing..." );
     my $ticket = $wf->context->param( 'ticket' );
