@@ -5,7 +5,8 @@ package App::Condition::HasUserAndTicket;
 use strict;
 use parent qw( Workflow::Condition );
 use Log::Any qw( $log );
-use Workflow::Exception qw( condition_error );
+use Workflow::Condition::IsFalse;
+use Workflow::Condition::IsTrue;
 
 $App::Condition::HasUserAndTicket::VERSION = '1.02';
 
@@ -16,8 +17,9 @@ sub evaluate {
     my $ticket = $wf->context->param( 'ticket' );
     $log->info( "[Current user: $current_user] [Ticket: $ticket]" );
     unless ( $current_user and $ticket ) {
-        condition_error "Values for 'current_user' and 'ticket' must be available";
+         return Workflow::Condition::IsFalse->new();
     }
+    return Workflow::Condition::IsTrue->new();
 }
 
 1;
