@@ -9,7 +9,7 @@ use Workflow::Exception qw( configuration_error );
 use Carp qw(croak);
 use Syntax::Keyword::Try;
 
-$Workflow::Config::YAML::VERSION = '2.05';
+$Workflow::Config::YAML::VERSION = '2.06';
 
 my $YAML_REQUIRED = 0;
 
@@ -78,7 +78,7 @@ Workflow::Config::YAML - Parse workflow configurations as YAML data structures
 
 =head1 VERSION
 
-This documentation describes version 2.05 of this package
+This documentation describes version 2.06 of this package
 
 =head1 SYNOPSIS
 
@@ -136,72 +136,3 @@ Please see the F<LICENSE>
 Please see L<Workflow>
 
 =cut
-
-__END__
-
-=pod
-
-=head1 NAME
-
-Workflow::Config::Perl - Parse workflow configurations as Perl data structures
-
-=head1 VERSION
-
-This documentation describes version 2.05 of this package
-
-=head1 SYNOPSIS
-
- # either of these is acceptable
- my $parser = Workflow::Config->new( 'perl' );
- my $parser = Workflow::Config->new( 'pl' );
-
- my $conf = $parser->parse( 'condition',
-                            'my_conditions.pl', 'your_conditions.perl' );
-
-=head1 DESCRIPTION
-
-Implementation of configuration parser for serialized Perl data
-structures from files/data. See L<Workflow::Config> for C<parse()>
-description.
-
-=head1 METHODS
-
-=head2 parse
-
-This method is required implemented by L<Workflow::Config>.
-
-It takes two arguments:
-
-=over
-
-=item * a string indicating the type of configuration. For a complete list of
-types please refer to L<Workflow::Config>
-
-=item * a list of filenames containing at least a single file name
-
-=back
-
-The method returns a list of configuration parameters.
-
-=head1 SEE ALSO
-
-=over
-
-=item * L<Workflow::Config>
-
-=back
-
-=head1 COPYRIGHT
-
-Copyright (c) 2004-2021 Chris Winters. All rights reserved.
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
-Please see the F<LICENSE>
-
-=head1 AUTHORS
-
-Please see L<Workflow>
-
-=cut
